@@ -49,6 +49,7 @@ def auth_path() -> Path:
 
 # KEYS
 
+DESCRIPTION = "description"
 PROJECT_ID = "projectId"
 LANGUAGE = "language"
 LANGUAGES = "languages"
@@ -98,6 +99,7 @@ INTENT_ACCURACY = "i_acc"
 NER_METRICS = "nerPerformance"
 ENTITY_ACC = "e_acc"
 TRAINING_TIME = "trainingTime"
+ENTITY = "entity"
 MESSAGE = "message"
 MODELS = "models"
 N_REPLICAS = "nReplicas"
@@ -106,6 +108,14 @@ PARSED_RESPONSE = "parsedResponse"
 OUTPUT = "output"
 YES = "Yes"
 NO = "No"
+ENTITY_TYPE = "entityType"
+PRE_TRAINED = "pre-trained"
+LOOKUP = "lookup"
+SYNONYM = "synonym"
+REGEX = "regex"
+
+# supported entity types
+NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
 
 # Follow up Commands
 CREATE_PROJECT_COMMAND = "neuralspace nlu create-project --help"
@@ -117,3 +127,47 @@ PARSE_MODEL_COMMAND = "neuralspace nlu parse --help"
 # checking command
 
 APP_IS_INSTALLED = "App is already installed"
+
+# URLS
+LIST_ENTITY_URL = "api/nlu/v1/list/entity"
+
+# emojis
+BOOK = "📚"
+FAST_FORWARD = "⏩"
+CROSS = "❌"
+SAD_SMILEY = "😔"
+GREEN_TICK = "✅"
+BIN = "🗑️"
+NUMBERS_IN_SQUARE = "🔢"
+DOWN_ARROW = "⬇️"
+PEN_AND_PAPER = "📝"
+ARROW_UP = "⤴"
+PERSON_STANDING = "🧍"
+PERSON_DUMBELL = "🏋"
+SAND_CLOCK = "⏳"
+WRITING = "✍️"
+PIN = "📌"
+SOUP = "🍲"
+OM = "🕉️"
+HASH = "#️⃣"
+FINGER_RIGHT = "👉️"
+PERSON_TAKING = "🗣️"
+PERSON_HERE = "💁"
+KEY = "🗝"
+DOOR = "🚪"
+ROCKET = "🚀"
+
+# COLORS
+RED_START = "[red]"
+RED_END = "[/red]"
+ORANGE_START = "[orange]"
+ORANGE_END = "[/orange]"
+ORANGE3_START = "[orange3]"
+ORANGE3_END = "[/orange3]"
+DARK_ORANGE_START = "[dark_orange3]"
+DARK_ORANGE_END = "[/dark_orange3]"
+INFO = "[deep_sky_blue2]INFO[/deep_sky_blue2]"
+BOLD_START = "[bold]"
+BOLD_END = "[/bold]"
+LOGO_HASH = ""
+ERROR = f"{RED_START}ERROR{RED_END}"
