@@ -37,7 +37,7 @@ from neuralspace.nlu.apis import (
     wait_till_training_completes,
 )
 from neuralspace.nlu.constants import SUPPORTED_LANGUAGES, TRAINING_PROGRESS
-from neuralspace.nlu.rasa_converter.rasaconverter import RasaConverter
+from neuralspace.nlu.converters.rasaconverter import RasaConverter
 from neuralspace.utils import get_entity_list, print_logo, setup_logger
 
 console = Console()
